import { EventBus, EventBusSubscriberCb, Publish } from "./EventBus";
import { DocumentNode, GraphQLSchema } from "graphql";
export declare type DataCb = (data: {}) => Promise<unknown>;
interface SubscriptionConfig {
    queries: DocumentNode;
    schema: GraphQLSchema;
    cb: (bus: VanillaEventBus) => EventBusSubscriberCb;
    getSubscription: (topic: string, cb: DataCb) => void;
}
export interface EventBusPlugin {
    consumeStart?: (args: {
        topic: string;
    }) => void;
    consumeEnd?: (args: {
        topic: string;
    }) => void;
    consumeError?: (err: Error) => void;
    publishError?: (err: Error) => void;
    publishStart?: (args: {
        topic: string;
    }) => void;
    publishEnd?: (args: {
        topic: string;
    }) => void;
}
export declare class VanillaEventBus implements EventBus {
    config: {
        publisher?: {
            schema: GraphQLSchema;
            publishInit?: (topics: string[]) => Promise<unknown>;
            publishClose?: (topics: string[]) => Promise<unknown>;
            publish: (args: {
                topicName: string;
                data: {};
            }) => Promise<unknown>;
        };
        subscriber?: SubscriptionConfig;
        plugins?: EventBusPlugin[];
    };
    private consumeValidator;
    private publishValidator;
    constructor(config: {
        publisher?: {
            schema: GraphQLSchema;
            publishInit?: (topics: string[]) => Promise<unknown>;
            publishClose?: (topics: string[]) => Promise<unknown>;
            publish: (args: {
                topicName: string;
                data: {};
            }) => Promise<unknown>;
        };
        subscriber?: SubscriptionConfig;
        plugins?: EventBusPlugin[];
    });
    init: () => Promise<void>;
    private consume;
    publish: Publish;
    closeConsumer: () => Promise<void>;
    closePublisher: () => Promise<void>;
}
export {};
